"""
Coze platform environment variable constants.

This module defines all environment variable keys used by the Coze platform
to avoid hardcoding strings throughout the codebase.
"""

# Workload Identity Client Credentials
COZE_WORKLOAD_IDENTITY_CLIENT_ID = "COZE_WORKLOAD_IDENTITY_CLIENT_ID"
COZE_WORKLOAD_IDENTITY_CLIENT_SECRET = "COZE_WORKLOAD_IDENTITY_CLIENT_SECRET"
COZE_WORKLOAD_IDENTITY_TOKEN_ENDPOINT = "COZE_WORKLOAD_IDENTITY_TOKEN_ENDPOINT"
COZE_WORKLOAD_ACCESS_TOKEN_ENDPOINT = "COZE_WORKLOAD_ACCESS_TOKEN_ENDPOINT"

# Vibe Web/App User Login Related
COZE_AUTH_OIDC_DISCOVERY_URL = "COZE_AUTH_OIDC_DISCOVERY_URL"
COZE_AUTH_OIDC_CLIENT_ID = "COZE_AUTH_OIDC_CLIENT_ID"
COZE_AUTH_OIDC_CLIENT_SECRET = "COZE_AUTH_OIDC_CLIENT_SECRET"
COZE_AUTH_SESSION_SECRET = "COZE_AUTH_SESSION_SECRET"

# Compass Trace Related
COZE_LOOP_API_TOKEN = "COZE_LOOP_API_TOKEN"

# Project Metadata
COZE_PROJECT_ID = "COZE_PROJECT_ID"
COZE_PROJECT_SPACE_ID = "COZE_PROJECT_SPACE_ID"
COZE_PROJECT_ENV = "COZE_PROJECT_ENV"

# Coze Service Environment
COZE_SERVER_ENV = "COZE_SERVER_ENV"

# Integration Related
COZE_OUTBOUND_AUTH_ENDPOINT = "COZE_OUTBOUND_AUTH_ENDPOINT"
COZE_INTEGRATION_BASE_URL = "COZE_INTEGRATION_BASE_URL"

# Default values
DEFAULT_COZE_SERVER_ENV = "NONE"